/**************** -*- mode: java -*- ***************************

The contents of this file are subject to the Mozilla Public
License Version 1.1 (the "License"); you may not use this file
except in compliance with the License. You may obtain a copy of
the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS
IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
implied. See the License for the specific language governing
rights and limitations under the License.

The Original Code is Aphrodite Development Team code.

The Initial Developer of the Original Code is Aphrodite
Development Team.  Portions created by Aphrodite
Development Team are Copyright (C) 1999-2002
Aphrodite Development Team.
All Rights Reserved.

Contributor(s): 
                       Mark Anderson 
                       David Boswell 
                       Jeff Campbell 
                       Pete Collins 
                       Lorenzo De Tomasi 
                       Neil Deakin 
                       John Dobbins 
                       Klein Duijmpje 
                       Ben Goodger 
                       Julia Kleyman 
                       Lemming 
                       Aaron Leventhal 
                       Jason LoBrutto 
                       Anders Lund 
                       Petrus Lundqvist 
                       Brian Mathis 
                       Yusuf Motara 
                       Chris Nelson 
                       Robert O'Connor 
                       Isriya Paireepairit 
                       Dan Ridley 
                       Richard Shaw 
                       Tekhir 
                       Matthew Thomas 
                       Waldo 

**********************************************************/

const nsIWebNavigation = Components.interfaces.nsIWebNavigation;
var gPrintSettings = null;
var gChromeState = null; // chrome state before we went into print preview
var gOldCloseHandler = null; // close handler before we went into print preview
var gInPrintPreviewMode = false;

function getWebNavigation()
{
  try {
    return getBrowser().webNavigation;
  } catch (e) {
    return null;
  }
}

function BrowserReloadWithFlags(reloadFlags)
{
  /* First, we'll try to use the session history object to reload so 
   * that framesets are handled properly. If we're in a special 
   * window (such as view-source) that has no session history, fall 
   * back on using the web navigation's reload method.
   */

  var webNav = getWebNavigation();
  try {
    var sh = webNav.sessionHistory;
    if (sh)
      webNav = sh.QueryInterface(Components.interfaces.nsIWebNavigation);
  } catch (e) {
  }

  try {
    webNav.reload(reloadFlags);
  } catch (e) {
  }
}

/**************************** PRINT ***********************/

function showPrintPreviewToolbar()
{
  toggleAffectedChrome(true);
  const kXULNS = 
    "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";

  var printPreviewTB = document.createElementNS(kXULNS, "toolbar");
  printPreviewTB.setAttribute("printpreview", true);
  printPreviewTB.setAttribute("id", "print-preview-toolbar");

  var navTB = document.getElementById("nav-bar");
  navTB.parentNode.appendChild(printPreviewTB);
}

function BrowserExitPrintPreview()
{
  gInPrintPreviewMode = false;

  var browser = getBrowser();
  browser.setAttribute("handleCtrlPageUpDown", "true");

  // exit print preview galley mode in content area
  var ifreq = _content.QueryInterface(
    Components.interfaces.nsIInterfaceRequestor);
  var webBrowserPrint = ifreq.getInterface(
    Components.interfaces.nsIWebBrowserPrint);     
  webBrowserPrint.exitPrintPreview(); 
  _content.focus();

  // remove the print preview toolbar
  var navTB = document.getElementById("nav-bar");
  var printPreviewTB = document.getElementById("print-preview-toolbar");
  navTB.parentNode.removeChild(printPreviewTB);

  // restore chrome to original state
  toggleAffectedChrome(false);

  // restore old onclose handler if we found one before previewing
  var mainWin = document.getElementById("main-window");
  mainWin.setAttribute("onclose", gOldCloseHandler);
}

function GetPrintSettings(webBrowserPrint)
{
  var prevPS = gPrintSettings;

  try {
    if (gPrintSettings == null) {
      var useGlobalPrintSettings = true;
      var pref = Components.classes["@mozilla.org/preferences-service;1"]
                           .getService(Components.interfaces.nsIPrefBranch);
      if (pref) {
        useGlobalPrintSettings = pref.getBoolPref("print.use_global_printsettings", false);
      }

      if (useGlobalPrintSettings) {
        gPrintSettings = webBrowserPrint.globalPrintSettings;
      } else {
        gPrintSettings = webBrowserPrint.newPrintSettings;
      }
    }
  } catch (e) {
    dump("GetPrintSettings "+e);
  }

  return gPrintSettings;
}

function BrowserPrintPreview()
{
  gInPrintPreviewMode = true;

  var browser = getBrowser();
  browser.setAttribute("handleCtrlPageUpDown", "false");

  var mainWin = document.getElementById("main-window");

  // save previous close handler to restoreon exiting print preview mode
  if (mainWin.hasAttribute("onclose"))
    gOldCloseHandler = mainWin.getAttribute("onclose");
  else
    gOldCloseHandler = null;
  mainWin.setAttribute("onclose", "BrowserExitPrintPreview(); return false;");
 
  try {
    var ifreq = _content.QueryInterface(
      Components.interfaces.nsIInterfaceRequestor);
    var webBrowserPrint = ifreq.getInterface(
      Components.interfaces.nsIWebBrowserPrint);     
    if (webBrowserPrint) {
      gPrintSettings = GetPrintSettings(webBrowserPrint);
      webBrowserPrint.printPreview(gPrintSettings);
    }

    // show the toolbar after we go into print preview mode so
    // that we can initialize the toolbar with total num pages
    showPrintPreviewToolbar();

    _content.focus();
  } catch (e) {
    // Pressing cancel is expressed as an NS_ERROR_ABORT return value,
    // causing an exception to be thrown which we catch here.
    // Unfortunately this will also consume helpful failures, so add a
    // dump(e); // if you need to debug
  }
}


function BrowserPrintSetup()
{

  try {
    var ifreq = _content.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
    var webBrowserPrint = ifreq.getInterface(Components.interfaces.nsIWebBrowserPrint);     
    if (webBrowserPrint) {
      gPrintSettings = GetPrintSettings(webBrowserPrint);
    }

    goPageSetup(gPrintSettings);  // from utilityOverlay.js

    if (webBrowserPrint) {
      if (webBrowserPrint.doingPrintPreview) {
        webBrowserPrint.printPreview(gPrintSettings);
      }
    }

  } catch (e) {
    dump("BrowserPrintSetup "+e);
  }
}

function BrowserPrint()
{
  try {
    var ifreq = _content.QueryInterface(Components.interfaces.nsIInterfaceRequestor);
    var webBrowserPrint = ifreq.getInterface(Components.interfaces.nsIWebBrowserPrint);     
    if (webBrowserPrint) {
      gPrintSettings = GetPrintSettings(webBrowserPrint);
      webBrowserPrint.print(gPrintSettings, null);
    }
  } catch (e) {
    // Pressing cancel is expressed as an NS_ERROR_ABORT return value,
    // causing an exception to be thrown which we catch here.
    // Unfortunately this will also consume helpful failures, so add a
    // dump(e); // if you need to debug
  }
}

/**************************** PRINT ***********************/

/**************************** FIND ******************************/

function BrowserFind()
{
  var focusedWindow = document.commandDispatcher.focusedWindow;
  if (!focusedWindow || focusedWindow == window)
    focusedWindow = window._content;

  findInPage(getBrowser(), window._content, focusedWindow)
}

function BrowserFindAgain()
{
    var focusedWindow = document.commandDispatcher.focusedWindow;
    if (!focusedWindow || focusedWindow == window)
      focusedWindow = window._content;

  findAgainInPage(getBrowser(), window._content, focusedWindow)
}

function BrowserCanFindAgain()
{
  return canFindAgainInPage();
}

/**************************** FIND ******************************/